@@ -7,7 +7,7 @@ import warnings
 warnings.filterwarnings('ignore')
 
 
-from .outliers import remove_outliers
+from outliers import remove_outliers
 
 def eda_data_quality (data):
     
@@ -161,7 +161,7 @@ class binary_eda_plot:
         
     def get_plots(self):  
 
-        fig2 = plt.figure(figsize=(self.width, self.length))
+        fig2 = plt.figure(figsize=(self.width, self.length), constrained_layout=True)
 
         j = 0
 
@@ -196,4 +196,4 @@ class binary_eda_plot:
 
         plt.subplots_adjust(wspace=0.4, hspace=0.25)
 
-        plt.show()
+        plt.tight_layout()
