@@ -17,10 +17,10 @@ from sklearn import metrics
 
 
 
-from .configuration import config
+from configuration import config
 
 # from configuration import config 
-from .jsonSerializer import NpEncoder
+from jsonSerializer import NpEncoder
 
 sns.set_style('whitegrid')
 warnings.filterwarnings('ignore')
