@@ -1,7 +1,7 @@
 from scipy import stats
 import copy
 
-from .configuration import config 
+from configuration import config 
 
 class remove_outliers:
     """
